@@ -17,6 +17,12 @@ mcfork <- function(...) parallel:::mcfork(...)
 
 mckill <- function(...) parallel:::mckill(...)
 
+mc.reset.stream <- function(...) parallel::mc.reset.stream(...)
+
+mcparallel <- function(...) parallel::mcparallel(...)
+
+mccollect <- function(...) parallel::mccollect(...)
+
 processID <-function(...) parallel:::processID(...)
 
 readChild <- function(...) parallel:::readChild(...)
@@ -30,12 +36,12 @@ setLoadActions(.registerDefaultParams = function(nmspc) {
         ## these fail under complex conditions, e.g., loading a data
         ## set with a class defined in a package that imports
         ## BiocParallel
-        register(getOption("SerialParam", SerialParam()))
-        register(getOption("BatchJobsParam", BatchJobsParam()))
-        register(getOption("SnowParam", SnowParam(workers=detectCores())))
-        register(getOption("MulticoreParam", MulticoreParam()))
+        register(getOption("MulticoreParam", MulticoreParam()), TRUE)
+        register(getOption("SnowParam", SnowParam()), FALSE)
+        register(getOption("SerialParam", SerialParam()), FALSE)
     }, error=function(err) {
-        message("'BiocParallel' did not register default BiocParallelParams")
+        message("'BiocParallel' did not register default ",
+                "BiocParallelParams:\n  ", conditionMessage(err))
         NULL
     })
 })
