@@ -1,5 +1,8 @@
 mclapply <- parallel::mclapply
 
+.bpiterate <- function(ITER, FUN, ...)
+    bpiterate(ITER, FUN, ..., BPPARAM=SerialParam())
+
 isChild <- function() {
     FALSE
 }
@@ -15,10 +18,8 @@ setLoadActions(.registerDefaultParams = function(nmspc) {
         ## these fail under complex conditions, e.g., loading a data
         ## set with a class defined in a package that imports
         ## BiocParallel
-        register(getOption("SerialParam", SerialParam()))
-        register(getOption("BatchJobsParam", BatchJobsParam()))
-        register(getOption("SnowParam", SnowParam(workers=detectCores())))
-        register(getOption("MulticoreParam", MulticoreParam()))
+        register(getOption("SnowParam", SnowParam()), TRUE)
+        register(getOption("SerialParam", SerialParam()), FALSE)
     }, error=function(err) {
         message("'BiocParallel' did not register default BiocParallelParams")
         NULL
